;;; roam.el -*- lexical-binding: t; -*-

(after! org-roam
  (setq org-roam-capture-templates
        '(("d" "default" plain
           "%?"
           :target
           (file+head
            "${slug}.org"
            "#+title: ${title}\n")
           :unnarrowed t)
          ("n" "literature note" plain
           "%?"
           :target
           (file+head
            "%(concat
     (when citar-org-roam-subdir (concat citar-org-roam-subdir \"/\")) \"${citekey}.org\")"
            "#+title: ${title}\n")
           :unnarrowed t)))
  (setq org-roam-dailies-capture-templates
        '(("d" "default" entry
           "* %?"
           :target (file+head "%<%Y-%m-%d>.org"
                              "#+title: %<%Y-%m-%d>\n"))))
  (map! :leader
        :desc "Capture today" "n n" #'org-roam-dailies-capture-today)
  (setq org-roam-directory (concat org-directory "roam/")
        org-roam-completion-everywhere nil))

(after! org-download
  (setq org-download-screenshot-method "flameshot gui --raw > %s"))

(after! citar
  ;; (setq citar-file-parser-functions
  ;;       '(citar-file--parser-default
  ;;         citar-file--parser-triplet))
  (setq citar-org-roam-capture-template-key "n")
  (setq! citar-library-paths '("~/Zotero" "~/Nextcloud/Calibre")
         citar-notes-paths `(,(expand-file-name "reference" org-roam-directory))
         citar-bibliography `(,(expand-file-name "library.bib" org-roam-directory)
                              ,(expand-file-name "books.bib" org-roam-directory))))

(after! citar-org-roam
  ;; (citar-register-notes-source
  ;; 'orb-citar-source (list :name "Org-Roam Notes"
  ;;         :category 'org-roam-node
  ;;         :items #'citar-org-roam--get-candidates
  ;;         :hasitems #'citar-org-roam-has-notes
  ;;         :open #'citar-org-roam-open-note
  ;;         :create #'orb-citar-edit-note
  ;;         :annotate #'citar-org-roam--annotate))
  ;; (setq citar-notes-source 'orb-citar-source)
  (setq citar-org-roam-subdir "reference"))

;; insert drawings from my RM2
(use-package! org-inline-pdf
  :hook (org-mode . org-inline-pdf-mode))

(use-package! org-roam-ui
  :after org-roam
  :config
  (setq org-roam-ui-sync-theme t
        org-roam-ui-follow t
        org-roam-ui-update-on-save t
        org-roam-ui-open-on-start t))

(after! org-noter
  ;; (map! :map pdf-view-mode-map "i" nil)
  ;; (map! :map pdf-view-mode-map :gn "i" #'org-noter-insert-note)
  (setq org-noter-always-create-frame nil))

(use-package! nov
  :mode ("\\.epub\\'" . nov-mode))

(use-package! org-transclusion
  :after org
  :init
  (map!
   :map global-map "<f12>" #'org-transclusion-add
   :leader
   :prefix "n"
   :desc "Org Transclusion Mode" "t" #'org-transclusion-mode))

(after! org-roam-bibtex
  (setq orb-insert-link-description 'citekey))
